# pybiotools
> Command tools in bioinformatics analysis wrapper in this python package, with default parameters and could be specify in specific analysis.


TODO.

## Install

`pip install pybiotools`

## Tools included

### fastp


### fastqc

### STAR

### hisat2

### samtools

### stringtie

### featurecounts
